Admin APIs
==========

**Note**: The latest documentation can be viewed `here <https://matrix-org.github.io/synapse>`_.
See `docs/README.md <../README.md>`_ for more information.

**Please update links to point to the website instead.** Existing files in this directory
are preserved to maintain historical links, but may be moved in the future.

This directory includes documentation for the various synapse specific admin
APIs available. Updates to the existing Admin API documentation should still
be made to these files, but any new documentation files should instead be placed under
`docs/usage/administration/admin_api <../usage/administration/admin_api>`_.

